@@ -1,9 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    John Oliver, Marc R. Hoffmann, Jan Wloka - initial API and implementation
@@ -32,24 +33,24 @@ import org.jacoco.report.IReportGroupVisitor;
  * <p>
  * Creates a structured code coverage report (HTML, XML, and CSV) from multiple
  * projects within reactor. The report is created from all modules this project
- * depends on. From those projects class and source files as well as JaCoCo
- * execution data files will be collected. In addition execution data is
- * collected from the project itself. This also allows to create coverage
- * reports when tests are in separate projects than the code under test, for
- * example in case of integration tests.
+ * depends on, and optionally this project itself. From those projects class and
+ * source files as well as JaCoCo execution data files will be collected. In
+ * addition execution data is collected from the project itself. This also
+ * allows to create coverage reports when tests are in separate projects than
+ * the code under test, for example in case of integration tests.
  * </p>
- * 
+ *
  * <p>
  * Using the dependency scope allows to distinguish projects which contribute
  * execution data but should not become part of the report:
  * </p>
- * 
+ *
  * <ul>
  * <li><code>compile</code>, <code>runtime</code>, <code>provided</code>:
  * Project source and execution data is included in the report.</li>
  * <li><code>test</code>: Only execution data is considered for the report.</li>
  * </ul>
- * 
+ *
  * @since 0.7.7
  */
 @Mojo(name = "report-aggregate", threadSafe = true)
@@ -81,6 +82,15 @@ public class ReportAggregateMojo extends AbstractReportMojo {
 	@Parameter(defaultValue = "${project.reporting.outputDirectory}/jacoco-aggregate")
 	private File outputDirectory;
 
+	/**
+	 * Include this project in the report. If true then this projects class and
+	 * source files as well as JaCoCo execution data files will be collected.
+	 *
+	 * @since 0.8.9
+	 */
+	@Parameter(defaultValue = "false")
+	private boolean includeCurrentProject;
+
 	/**
 	 * The projects in the reactor.
 	 */
@@ -106,7 +116,7 @@ public class ReportAggregateMojo extends AbstractReportMojo {
 
 		final FileFilter filter = new FileFilter(dataFileIncludes,
 				dataFileExcludes);
-		loadExecutionData(support, filter, getProject().getBasedir());
+		loadExecutionData(support, filter, project.getBasedir());
 		for (final MavenProject dependency : findDependencies(
 				Artifact.SCOPE_COMPILE, Artifact.SCOPE_RUNTIME,
 				Artifact.SCOPE_PROVIDED, Artifact.SCOPE_TEST)) {
@@ -122,34 +132,38 @@ public class ReportAggregateMojo extends AbstractReportMojo {
 	}
 
 	@Override
-	void addFormatters(final ReportSupport support, final Locale locale)
-			throws IOException {
-		support.addAllFormatters(outputDirectory, outputEncoding, footer,
-				locale);
+	File getOutputDirectory() {
+		return outputDirectory;
 	}
 
 	@Override
 	void createReport(final IReportGroupVisitor visitor,
 			final ReportSupport support) throws IOException {
 		final IReportGroupVisitor group = visitor.visitGroup(title);
+		if (includeCurrentProject) {
+			processProject(support, group, project);
+		}
 		for (final MavenProject dependency : findDependencies(
 				Artifact.SCOPE_COMPILE, Artifact.SCOPE_RUNTIME,
 				Artifact.SCOPE_PROVIDED)) {
-			support.processProject(group, dependency.getArtifactId(),
-					dependency, getIncludes(), getExcludes(), sourceEncoding);
+			processProject(support, group, dependency);
 		}
 	}
 
-	@Override
-	protected String getOutputDirectory() {
-		return outputDirectory.getAbsolutePath();
+	private void processProject(final ReportSupport support,
+			final IReportGroupVisitor group, final MavenProject project)
+			throws IOException {
+		support.processProject(group, project.getArtifactId(), project,
+				getIncludes(), getExcludes(), sourceEncoding);
+	}
+
+	public File getReportOutputDirectory() {
+		return outputDirectory;
 	}
 
-	@Override
 	public void setReportOutputDirectory(final File reportOutputDirectory) {
-		if (reportOutputDirectory != null
-				&& !reportOutputDirectory.getAbsolutePath().endsWith(
-						"jacoco-aggregate")) {
+		if (reportOutputDirectory != null && !reportOutputDirectory
+				.getAbsolutePath().endsWith("jacoco-aggregate")) {
 			outputDirectory = new File(reportOutputDirectory,
 					"jacoco-aggregate");
 		} else {
@@ -168,7 +182,7 @@ public class ReportAggregateMojo extends AbstractReportMojo {
 	private List<MavenProject> findDependencies(final String... scopes) {
 		final List<MavenProject> result = new ArrayList<MavenProject>();
 		final List<String> scopeList = Arrays.asList(scopes);
-		for (final Object dependencyObject : getProject().getDependencies()) {
+		for (final Object dependencyObject : project.getDependencies()) {
 			final Dependency dependency = (Dependency) dependencyObject;
 			if (scopeList.contains(dependency.getScope())) {
 				final MavenProject project = findProjectFromReactor(dependency);
@@ -192,7 +206,7 @@ public class ReportAggregateMojo extends AbstractReportMojo {
 		try {
 			depVersionAsRange = VersionRange
 					.createFromVersionSpec(d.getVersion());
-		} catch (InvalidVersionSpecificationException e) {
+		} catch (final InvalidVersionSpecificationException e) {
 			throw new AssertionError(e);
 		}
 
