@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.agent.rt.internal;
 
@@ -39,12 +40,15 @@ public class Agent implements IAgent {
 	/**
 	 * Returns a global instance which is already started. If the method is
 	 * called the first time the instance is created with the given options.
-	 * 
+	 *
 	 * @param options
 	 *            options to configure the instance
 	 * @return global instance
+	 * @throws Exception
+	 *             in case something cannot be initialized
 	 */
-	public static synchronized Agent getInstance(final AgentOptions options) {
+	public static synchronized Agent getInstance(final AgentOptions options)
+			throws Exception {
 		if (singleton == null) {
 			final Agent agent = new Agent(options, IExceptionLogger.SYSTEM_ERR);
 			agent.startup();
@@ -62,12 +66,13 @@ public class Agent implements IAgent {
 	/**
 	 * Returns a global instance which is already started. If a agent has not
 	 * been initialized before this method will fail.
-	 * 
+	 *
 	 * @return global instance
 	 * @throws IllegalStateException
 	 *             if no Agent has been started yet
 	 */
-	public static synchronized Agent getInstance() throws IllegalStateException {
+	public static synchronized Agent getInstance()
+			throws IllegalStateException {
 		if (singleton == null) {
 			throw new IllegalStateException("JaCoCo agent not started.");
 		}
@@ -86,7 +91,7 @@ public class Agent implements IAgent {
 
 	/**
 	 * Creates a new agent with the given agent options.
-	 * 
+	 *
 	 * @param options
 	 *            agent options
 	 * @param logger
@@ -100,7 +105,7 @@ public class Agent implements IAgent {
 
 	/**
 	 * Returns the runtime data object created by this agent
-	 * 
+	 *
 	 * @return runtime data for this agent instance
 	 */
 	public RuntimeData getData() {
@@ -109,9 +114,11 @@ public class Agent implements IAgent {
 
 	/**
 	 * Initializes this agent.
-	 * 
+	 *
+	 * @throws Exception
+	 *             in case something cannot be initialized
 	 */
-	public void startup() {
+	public void startup() throws Exception {
 		try {
 			String sessionId = options.getSessionId();
 			if (sessionId == null) {
@@ -125,6 +132,7 @@ public class Agent implements IAgent {
 			}
 		} catch (final Exception e) {
 			logger.logExeption(e);
+			throw e;
 		}
 	}
 
@@ -147,7 +155,7 @@ public class Agent implements IAgent {
 
 	/**
 	 * Create output implementation as given by the agent options.
-	 * 
+	 *
 	 * @return configured controller implementation
 	 */
 	IAgentOutput createAgentOutput() {
