@@ -1,9 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Evgeny Mandrikov - initial API and implementation
@@ -24,6 +25,11 @@ object KotlinCoroutineTarget {
         nop() // assertFullyCovered()
     } // assertFullyCovered()
 
+    private suspend fun suspendingFunctionWithTailCallOptimization() { // assertEmpty()
+        nop() // assertFullyCovered()
+        anotherSuspendingFunction() // assertFullyCovered()
+    } // assertFullyCovered()
+
     private suspend fun anotherSuspendingFunction() {
         nop() // assertFullyCovered()
     }
@@ -36,6 +42,7 @@ object KotlinCoroutineTarget {
             nop(x) // assertFullyCovered()
             suspendingFunction() // assertFullyCovered()
             nop(x) // assertFullyCovered()
+            suspendingFunctionWithTailCallOptimization()
         } // assertFullyCovered()
 
     }
