@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.analysis;
 
@@ -110,12 +111,14 @@ public class CounterComparatorTest {
 
 	private void assertCmpLess(Comparator<ICounter> cmp, int missed1,
 			int covered1, int missed2, int covered2) {
-		assertTrue(cmp.compare(ctr(missed1, covered1), ctr(missed2, covered2)) < 0);
+		assertTrue(cmp.compare(ctr(missed1, covered1),
+				ctr(missed2, covered2)) < 0);
 	}
 
 	private void assertCmpGreater(Comparator<ICounter> cmp, int missed1,
 			int covered1, int missed2, int covered2) {
-		assertTrue(cmp.compare(ctr(missed1, covered1), ctr(missed2, covered2)) > 0);
+		assertTrue(cmp.compare(ctr(missed1, covered1),
+				ctr(missed2, covered2)) > 0);
 	}
 
 	private CounterImpl ctr(int missed, int covered) {
