@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.analysis;
 
@@ -141,13 +142,13 @@ public class CoverageBuilderTest {
 
 	@Test
 	public void testCreateSourceFile() {
-		final MethodCoverageImpl method1 = new MethodCoverageImpl("doit",
-				"()V", null);
+		final MethodCoverageImpl method1 = new MethodCoverageImpl("doit", "()V",
+				null);
 		method1.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 3);
 		addClass(123L, false, "Sample", "Sample.java", method1);
 
-		final MethodCoverageImpl method2 = new MethodCoverageImpl("doit",
-				"()V", null);
+		final MethodCoverageImpl method2 = new MethodCoverageImpl("doit", "()V",
+				null);
 		method2.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 6);
 		addClass(234L, false, "Second", "Sample.java", method2);
 
@@ -162,13 +163,13 @@ public class CoverageBuilderTest {
 
 	@Test
 	public void testCreateSourceFileDuplicateClassNameIdentical() {
-		final MethodCoverageImpl method1 = new MethodCoverageImpl("doit",
-				"()V", null);
+		final MethodCoverageImpl method1 = new MethodCoverageImpl("doit", "()V",
+				null);
 		method1.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 3);
 		addClass(123L, false, "Sample", "Sample.java", method1);
 
-		final MethodCoverageImpl method2 = new MethodCoverageImpl("doit",
-				"()V", null);
+		final MethodCoverageImpl method2 = new MethodCoverageImpl("doit", "()V",
+				null);
 		method2.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 3);
 		addClass(123L, false, "Sample", "Sample.java", method2);
 
@@ -183,18 +184,18 @@ public class CoverageBuilderTest {
 
 	@Test
 	public void testGetBundle() {
-		final MethodCoverageImpl method1 = new MethodCoverageImpl("doit",
-				"()V", null);
+		final MethodCoverageImpl method1 = new MethodCoverageImpl("doit", "()V",
+				null);
 		method1.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 3);
 		addClass(1, false, "org/jacoco/examples/Sample1", null, method1);
 
-		final MethodCoverageImpl method2 = new MethodCoverageImpl("doit",
-				"()V", null);
+		final MethodCoverageImpl method2 = new MethodCoverageImpl("doit", "()V",
+				null);
 		method2.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 6);
 		addClass(2, false, "org/jacoco/examples/Sample2", null, method2);
 
-		final MethodCoverageImpl method3 = new MethodCoverageImpl("doit",
-				"()V", null);
+		final MethodCoverageImpl method3 = new MethodCoverageImpl("doit", "()V",
+				null);
 		method3.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 1);
 		addClass(3, false, "Sample3", null, method3);
 
@@ -211,8 +212,7 @@ public class CoverageBuilderTest {
 		IPackageCoverage p1 = packagesByName.get("org/jacoco/examples");
 		assertNotNull(p1);
 		assertEquals(
-				new HashSet<String>(Arrays.asList(
-						"org/jacoco/examples/Sample1",
+				new HashSet<String>(Arrays.asList("org/jacoco/examples/Sample1",
 						"org/jacoco/examples/Sample2")),
 				getNames(p1.getClasses()));
 
@@ -236,9 +236,10 @@ public class CoverageBuilderTest {
 		m.increment(CounterImpl.COUNTER_1_0, CounterImpl.COUNTER_0_0, 3);
 		addClass(3, false, "Sample3", null, m);
 
-		final Set<String> actual = getNames(coverageBuilder.getNoMatchClasses());
-		final Set<String> expected = new HashSet<String>(Arrays.asList(
-				"Sample1", "Sample2"));
+		final Set<String> actual = getNames(
+				coverageBuilder.getNoMatchClasses());
+		final Set<String> expected = new HashSet<String>(
+				Arrays.asList("Sample1", "Sample2"));
 
 		assertEquals(expected, actual);
 	}
