@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.analysis;
 
@@ -52,7 +53,8 @@ public class CoverageNodeImplTest {
 	public void testIncrement() {
 		CoverageNodeImpl parent = new CoverageNodeImpl(ElementType.GROUP,
 				"sample");
-		ICoverageNode child = new CoverageNodeImpl(ElementType.GROUP, "sample") {
+		ICoverageNode child = new CoverageNodeImpl(ElementType.GROUP,
+				"sample") {
 			{
 				instructionCounter = CounterImpl.getInstance(1, 41);
 				branchCounter = CounterImpl.getInstance(10, 15);
@@ -67,8 +69,10 @@ public class CoverageNodeImplTest {
 				parent.getCounter(INSTRUCTION));
 		assertEquals(CounterImpl.getInstance(1, 41),
 				parent.getInstructionCounter());
-		assertEquals(CounterImpl.getInstance(10, 15), parent.getCounter(BRANCH));
-		assertEquals(CounterImpl.getInstance(10, 15), parent.getBranchCounter());
+		assertEquals(CounterImpl.getInstance(10, 15),
+				parent.getCounter(BRANCH));
+		assertEquals(CounterImpl.getInstance(10, 15),
+				parent.getBranchCounter());
 		assertEquals(CounterImpl.getInstance(5, 3), parent.getCounter(LINE));
 		assertEquals(CounterImpl.getInstance(5, 3), parent.getLineCounter());
 		assertEquals(CounterImpl.getInstance(4, 2),
@@ -85,12 +89,14 @@ public class CoverageNodeImplTest {
 	public void testIncrementCollection() {
 		CoverageNodeImpl parent = new CoverageNodeImpl(ElementType.GROUP,
 				"sample");
-		ICoverageNode child1 = new CoverageNodeImpl(ElementType.GROUP, "sample") {
+		ICoverageNode child1 = new CoverageNodeImpl(ElementType.GROUP,
+				"sample") {
 			{
 				branchCounter = CounterImpl.getInstance(5, 2);
 			}
 		};
-		ICoverageNode child2 = new CoverageNodeImpl(ElementType.GROUP, "sample") {
+		ICoverageNode child2 = new CoverageNodeImpl(ElementType.GROUP,
+				"sample") {
 			{
 				branchCounter = CounterImpl.getInstance(3, 3);
 			}
@@ -120,7 +126,8 @@ public class CoverageNodeImplTest {
 		assertEquals(CounterImpl.getInstance(4, 4),
 				copy.getInstructionCounter());
 		assertEquals(CounterImpl.getInstance(5, 5), copy.getLineCounter());
-		assertEquals(CounterImpl.getInstance(6, 6), copy.getComplexityCounter());
+		assertEquals(CounterImpl.getInstance(6, 6),
+				copy.getComplexityCounter());
 	}
 
 	@Test
