@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.analysis;
 
@@ -34,9 +35,9 @@ public class NodeComparatorTest {
 		ICoverageNode d3 = new MockNode(30);
 		ICoverageNode d4 = new MockNode(60);
 		ICoverageNode d5 = new MockNode(99);
-		final List<ICoverageNode> result = CounterComparator.TOTALITEMS.on(
-				CounterEntity.INSTRUCTION).sort(
-				Arrays.asList(d3, d5, d1, d4, d2));
+		final List<ICoverageNode> result = CounterComparator.TOTALITEMS
+				.on(CounterEntity.INSTRUCTION)
+				.sort(Arrays.asList(d3, d5, d1, d4, d2));
 		assertEquals(Arrays.asList(d1, d2, d3, d4, d5), result);
 	}
 
