@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.internal.analysis;
 
@@ -28,12 +29,12 @@ public class PackageCoverageTest {
 
 	@Test
 	public void testProperties() {
-		Collection<IClassCoverage> classes = Collections
-				.singleton((IClassCoverage) new ClassCoverageImpl(
-						"org/jacoco/test/Sample", 0, false));
-		Collection<ISourceFileCoverage> sourceFiles = Collections
-				.singleton((ISourceFileCoverage) new SourceFileCoverageImpl(
-						"Sample.java", "org/jacoco/test/Sample"));
+		Collection<IClassCoverage> classes = Collections.singleton(
+				(IClassCoverage) new ClassCoverageImpl("org/jacoco/test/Sample",
+						0, false));
+		Collection<ISourceFileCoverage> sourceFiles = Collections.singleton(
+				(ISourceFileCoverage) new SourceFileCoverageImpl("Sample.java",
+						"org/jacoco/test/Sample"));
 		PackageCoverageImpl data = new PackageCoverageImpl("org/jacoco/test",
 				classes, sourceFiles);
 		assertEquals(ICoverageNode.ElementType.PACKAGE, data.getElementType());
