@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.internal.flow;
 
@@ -31,14 +32,14 @@ public class ClassProbesAdapterTest {
 		boolean frame = false;
 
 		@Override
-		public void visitJumpInsnWithProbe(int opcode, Label label,
-				int probeId, IFrame frame) {
+		public void visitJumpInsnWithProbe(int opcode, Label label, int probeId,
+				IFrame frame) {
 			frame.accept(this);
 		}
 
 		@Override
-		public void visitTableSwitchInsnWithProbes(int min, int max,
-				Label dflt, Label[] labels, IFrame frame) {
+		public void visitTableSwitchInsnWithProbes(int min, int max, Label dflt,
+				Label[] labels, IFrame frame) {
 			frame.accept(this);
 		}
 
@@ -49,8 +50,8 @@ public class ClassProbesAdapterTest {
 		}
 
 		@Override
-		public void visitFrame(int type, int nLocal, Object[] local,
-				int nStack, Object[] stack) {
+		public void visitFrame(int type, int nLocal, Object[] local, int nStack,
+				Object[] stack) {
 			frame = true;
 		}
 	}
