@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.internal.flow;
 
@@ -63,16 +64,16 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 		}
 
 		@Override
-		public void visitJumpInsnWithProbe(int opcode, Label label,
-				int probeId, IFrame frame) {
+		public void visitJumpInsnWithProbe(int opcode, Label label, int probeId,
+				IFrame frame) {
 			rec("visitJumpInsnWithProbe", Integer.valueOf(opcode), label,
 					Integer.valueOf(probeId));
 			frame.accept(this);
 		}
 
 		@Override
-		public void visitTableSwitchInsnWithProbes(int min, int max,
-				Label dflt, Label[] labels, IFrame frame) {
+		public void visitTableSwitchInsnWithProbes(int min, int max, Label dflt,
+				Label[] labels, IFrame frame) {
 			rec("visitTableSwitchInsnWithProbes", Integer.valueOf(min),
 					Integer.valueOf(max), dflt, labels);
 			frame.accept(this);
@@ -170,10 +171,10 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 
 		adapter.visitJumpInsn(Opcodes.GOTO, label);
 
-		expectedVisitor
-				.visitJumpInsnWithProbe(Opcodes.GOTO, label, 1000, frame);
-		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" },
-				0, null);
+		expectedVisitor.visitJumpInsnWithProbe(Opcodes.GOTO, label, 1000,
+				frame);
+		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" }, 0,
+				null);
 	}
 
 	@Test
@@ -185,10 +186,10 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 		adapter.visitJumpInsn(Opcodes.IFLT, label);
 
 		expectedVisitor.visitInsn(Opcodes.ICONST_0);
-		expectedVisitor
-				.visitJumpInsnWithProbe(Opcodes.IFLT, label, 1000, frame);
-		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" },
-				0, null);
+		expectedVisitor.visitJumpInsnWithProbe(Opcodes.IFLT, label, 1000,
+				frame);
+		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" }, 0,
+				null);
 	}
 
 	@Test
@@ -213,8 +214,8 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 		expectedVisitor.visitInsn(Opcodes.ICONST_0);
 		expectedVisitor.visitJumpInsnWithProbe(Opcodes.IF_ICMPEQ, label, 1000,
 				frame);
-		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" },
-				0, null);
+		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" }, 0,
+				null);
 	}
 
 	@Test
@@ -230,8 +231,8 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 		expectedVisitor.visitInsn(Opcodes.ICONST_0);
 		expectedVisitor.visitLookupSwitchInsnWithProbes(label, keys, labels,
 				frame);
-		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" },
-				0, null);
+		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" }, 0,
+				null);
 		assertEquals(1000, LabelInfo.getProbeId(label));
 	}
 
@@ -249,8 +250,8 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 		expectedVisitor.visitInsn(Opcodes.ICONST_0);
 		expectedVisitor.visitLookupSwitchInsnWithProbes(label, keys, labels,
 				frame);
-		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" },
-				0, null);
+		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" }, 0,
+				null);
 		assertEquals(LabelInfo.NO_PROBE, LabelInfo.getProbeId(label));
 		assertEquals(1000, LabelInfo.getProbeId(label2));
 	}
@@ -278,8 +279,8 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 		expectedVisitor.visitInsn(Opcodes.ICONST_0);
 		expectedVisitor.visitTableSwitchInsnWithProbes(0, 1, label, labels,
 				frame);
-		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" },
-				0, null);
+		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" }, 0,
+				null);
 		assertEquals(1000, LabelInfo.getProbeId(label));
 	}
 
@@ -296,8 +297,8 @@ public class MethodProbesAdapterTest implements IProbeIdGenerator {
 		expectedVisitor.visitInsn(Opcodes.ICONST_0);
 		expectedVisitor.visitTableSwitchInsnWithProbes(0, 1, label, labels,
 				frame);
-		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" },
-				0, null);
+		expectedVisitor.visitFrame(Opcodes.F_FULL, 1, new Object[] { "Foo" }, 0,
+				null);
 		assertEquals(LabelInfo.NO_PROBE, LabelInfo.getProbeId(label));
 		assertEquals(1000, LabelInfo.getProbeId(label2));
 	}
