@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.runtime;
 
@@ -30,8 +31,8 @@ import org.junit.Test;
  * The tests don't care about the written binary format, they just verify
  * symmetry.
  */
-public class RemoteControlReaderWriterTest extends
-		ExecutionDataReaderWriterTest {
+public class RemoteControlReaderWriterTest
+		extends ExecutionDataReaderWriterTest {
 
 	private RemoteControlWriter writer;
 
@@ -93,8 +94,8 @@ public class RemoteControlReaderWriterTest extends
 
 	@Override
 	protected RemoteControlReader createReader() throws IOException {
-		return new RemoteControlReader(new ByteArrayInputStream(
-				buffer.toByteArray()));
+		return new RemoteControlReader(
+				new ByteArrayInputStream(buffer.toByteArray()));
 	}
 
 	@Override
