@@ -1,9 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Evgeny Mandrikov - initial API and implementation
@@ -52,6 +53,10 @@ public final class InstrumentingLoader extends ClassLoader {
 	protected synchronized Class<?> loadClass(String name, boolean resolve)
 			throws ClassNotFoundException {
 		if (name.startsWith(scope)) {
+			Class<?> c = findLoadedClass(name);
+			if (c != null) {
+				return c;
+			}
 			final byte[] bytes;
 			try {
 				bytes = TargetLoader.getClassDataAsBytes(delegate, name);
@@ -64,8 +69,7 @@ public final class InstrumentingLoader extends ClassLoader {
 			} catch (IOException e) {
 				throw new ClassNotFoundException("Unable to instrument", e);
 			}
-			final Class<?> c = defineClass(name, instrumented, 0,
-					instrumented.length);
+			c = defineClass(name, instrumented, 0, instrumented.length);
 			if (resolve) {
 				resolveClass(c);
 			}
