@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.test.perf;
 
@@ -18,7 +19,6 @@ import org.jacoco.core.runtime.IRuntime;
 import org.jacoco.core.runtime.LoggerRuntime;
 import org.jacoco.core.runtime.RuntimeData;
 import org.jacoco.core.test.TargetLoader;
-import org.objectweb.asm.ClassReader;
 
 /**
  * This scenario runs a given scenario twice and reports the execution time:
@@ -37,11 +37,11 @@ public class ExecuteInstrumentedCodeScenario extends TimedScenario {
 	@Override
 	@SuppressWarnings("unchecked")
 	protected Callable<Void> getInstrumentedCallable() throws Exception {
-		ClassReader reader = new ClassReader(TargetLoader.getClassData(target));
 		IRuntime runtime = new LoggerRuntime();
 		runtime.startup(new RuntimeData());
 		final Instrumenter instr = new Instrumenter(runtime);
-		final byte[] instrumentedBuffer = instr.instrument(reader);
+		final byte[] original = TargetLoader.getClassDataAsBytes(target);
+		final byte[] instrumentedBuffer = instr.instrument(original, "");
 		final TargetLoader loader = new TargetLoader();
 
 		return (Callable<Void>) loader.add(target, instrumentedBuffer)
