@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.test.perf;
 
@@ -15,7 +16,6 @@ import org.jacoco.core.instr.Instrumenter;
 import org.jacoco.core.runtime.IRuntime;
 import org.jacoco.core.runtime.LoggerRuntime;
 import org.jacoco.core.test.TargetLoader;
-import org.objectweb.asm.ClassReader;
 
 /**
  * Scenario to measure the overhead in terms of additional byte code size
@@ -31,11 +31,11 @@ public class InstrumentationSizeSzenario implements IPerfScenario {
 
 	public void run(IPerfOutput output) throws Exception {
 		final IRuntime runtime = new LoggerRuntime();
-		ClassReader reader = new ClassReader(TargetLoader.getClassData(target));
 		final Instrumenter instr = new Instrumenter(runtime);
-		instr.instrument(reader);
-		output.writeByteResult("instrumented class",
-				instr.instrument(reader).length, reader.b.length);
+		final byte[] original = TargetLoader.getClassDataAsBytes(target);
+		final byte[] instrumented = instr.instrument(original, "");
+		output.writeByteResult("instrumented class", instrumented.length,
+				original.length);
 	}
 
 }
