@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.tools;
 
@@ -32,9 +33,7 @@ import org.jacoco.core.runtime.RemoteControlReader;
 import org.jacoco.core.runtime.RemoteControlWriter;
 import org.junit.After;
 import org.junit.Before;
-import org.junit.Rule;
 import org.junit.Test;
-import org.junit.rules.ExpectedException;
 
 /**
  * Unit tests for {@link ExecDumpClient}.
@@ -49,9 +48,6 @@ public class ExecDumpClientTest {
 
 	private ServerSocket server;
 
-	@Rule
-	public ExpectedException exception = ExpectedException.none();
-
 	@Before
 	public void setup() {
 		callbacks = new ArrayList<String>();
@@ -135,11 +131,13 @@ public class ExecDumpClientTest {
 	@Test
 	public void should_throw_IOException_when_server_closes_connection_without_response()
 			throws IOException {
-		exception.expect(IOException.class);
-		exception.expectMessage("Socket closed unexpectedly.");
-
 		int port = createNopServer();
-		client.dump((String) null, port);
+		try {
+			client.dump((String) null, port);
+			fail("exception expected");
+		} catch (IOException e) {
+			assertEquals("Socket closed unexpectedly.", e.getMessage());
+		}
 	}
 
 	private int getFreePort() throws IOException {
