@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.data;
 
@@ -30,7 +31,7 @@ public final class ExecutionData {
 
 	/**
 	 * Creates a new {@link ExecutionData} object with the given probe data.
-	 * 
+	 *
 	 * @param id
 	 *            class identifier
 	 * @param name
@@ -48,7 +49,7 @@ public final class ExecutionData {
 	/**
 	 * Creates a new {@link ExecutionData} object with the given probe data
 	 * length. All probes are set to <code>false</code>.
-	 * 
+	 *
 	 * @param id
 	 *            class identifier
 	 * @param name
@@ -56,7 +57,8 @@ public final class ExecutionData {
 	 * @param probeCount
 	 *            probe count
 	 */
-	public ExecutionData(final long id, final String name, final int probeCount) {
+	public ExecutionData(final long id, final String name,
+			final int probeCount) {
 		this.id = id;
 		this.name = name;
 		this.probes = new boolean[probeCount];
@@ -65,7 +67,7 @@ public final class ExecutionData {
 	/**
 	 * Return the unique identifier for this class. The identifier is the CRC64
 	 * checksum of the raw class file definition.
-	 * 
+	 *
 	 * @return class identifier
 	 */
 	public long getId() {
@@ -74,7 +76,7 @@ public final class ExecutionData {
 
 	/**
 	 * The VM name of the class.
-	 * 
+	 *
 	 * @return VM name
 	 */
 	public String getName() {
@@ -84,7 +86,7 @@ public final class ExecutionData {
 	/**
 	 * Returns the execution data probes. A value of <code>true</code> indicates
 	 * that the corresponding probe was executed.
-	 * 
+	 *
 	 * @return probe data
 	 */
 	public boolean[] getProbes() {
@@ -100,7 +102,7 @@ public final class ExecutionData {
 
 	/**
 	 * Checks whether any probe has been hit.
-	 * 
+	 *
 	 * @return <code>true</code>, if at least one probe has been hit
 	 */
 	public boolean hasHits() {
@@ -117,13 +119,13 @@ public final class ExecutionData {
 	 * a probe entry in this object is marked as executed (<code>true</code>) if
 	 * this probe or the corresponding other probe was executed. So the result
 	 * is
-	 * 
+	 *
 	 * <pre>
 	 * A or B
 	 * </pre>
-	 * 
+	 *
 	 * The probe array of the other object is not modified.
-	 * 
+	 *
 	 * @param other
 	 *            execution data to merge
 	 */
@@ -136,19 +138,19 @@ public final class ExecutionData {
 	 * probe in this object is set to the value of <code>flag</code> if the
 	 * corresponding other probe was executed. For <code>flag==true</code> this
 	 * corresponds to
-	 * 
+	 *
 	 * <pre>
 	 * A or B
 	 * </pre>
-	 * 
+	 *
 	 * For <code>flag==false</code> this can be considered as a subtraction
-	 * 
+	 *
 	 * <pre>
 	 * A and not B
 	 * </pre>
-	 * 
+	 *
 	 * The probe array of the other object is not modified.
-	 * 
+	 *
 	 * @param other
 	 *            execution data to merge
 	 * @param flag
@@ -169,7 +171,7 @@ public final class ExecutionData {
 	 * Asserts that this execution data object is compatible with the given
 	 * parameters. The purpose of this check is to detect a very unlikely class
 	 * id collision.
-	 * 
+	 *
 	 * @param id
 	 *            other class id, must be the same
 	 * @param name
@@ -182,14 +184,14 @@ public final class ExecutionData {
 	public void assertCompatibility(final long id, final String name,
 			final int probecount) throws IllegalStateException {
 		if (this.id != id) {
-			throw new IllegalStateException(format(
-					"Different ids (%016x and %016x).", Long.valueOf(this.id),
-					Long.valueOf(id)));
+			throw new IllegalStateException(
+					format("Different ids (%016x and %016x).",
+							Long.valueOf(this.id), Long.valueOf(id)));
 		}
 		if (!this.name.equals(name)) {
-			throw new IllegalStateException(format(
-					"Different class names %s and %s for id %016x.", this.name,
-					name, Long.valueOf(id)));
+			throw new IllegalStateException(
+					format("Different class names %s and %s for id %016x.",
+							this.name, name, Long.valueOf(id)));
 		}
 		if (this.probes.length != probecount) {
 			throw new IllegalStateException(format(
