@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.internal.flow;
 
@@ -27,7 +28,7 @@ public final class LabelFlowAnalyzer extends MethodVisitor {
 
 	/**
 	 * Marks all labels of the method with control flow information.
-	 * 
+	 *
 	 * @param method
 	 *            Method to mark labels
 	 */
@@ -100,6 +101,12 @@ public final class LabelFlowAnalyzer extends MethodVisitor {
 
 	@Override
 	public void visitLineNumber(final int line, final Label start) {
+		if (line == 0) {
+			// ASM versions prior to 9.5 were ignoring zero line numbers
+			// (https://gitlab.ow2.org/asm/asm/-/issues/317989)
+			// so we ignore them here to preserve exec file compatibility
+			return;
+		}
 		lineStart = start;
 	}
 
@@ -136,8 +143,6 @@ public final class LabelFlowAnalyzer extends MethodVisitor {
 	@Override
 	public void visitInsn(final int opcode) {
 		switch (opcode) {
-		case Opcodes.RET:
-			throw new AssertionError("Subroutines not supported.");
 		case Opcodes.IRETURN:
 		case Opcodes.LRETURN:
 		case Opcodes.FRETURN:
@@ -162,6 +167,9 @@ public final class LabelFlowAnalyzer extends MethodVisitor {
 
 	@Override
 	public void visitVarInsn(final int opcode, final int var) {
+		if (Opcodes.RET == opcode) {
+			throw new AssertionError("Subroutines not supported.");
+		}
 		successor = true;
 		first = false;
 	}
