@@ -1,18 +1,19 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.examples;
 
+import static org.hamcrest.CoreMatchers.containsString;
 import static org.jacoco.examples.ConsoleOutput.containsLine;
-import static org.junit.matchers.JUnitMatchers.containsString;
 
 import java.io.File;
 import java.io.FileOutputStream;
@@ -40,9 +41,11 @@ public class ExecDumpTest {
 		new ExecDump(console.stream).execute(args);
 
 		console.expect(containsLine("exec file: " + file));
-		console.expect(containsLine("CLASS ID         HITS/PROBES   CLASS NAME"));
+		console.expect(
+				containsLine("CLASS ID         HITS/PROBES   CLASS NAME"));
 		console.expect(containsString("Session \"testid\":"));
-		console.expect(containsLine("0000000000001234    2 of   3   foo/MyClass"));
+		console.expect(
+				containsLine("0000000000001234    2 of   3   foo/MyClass"));
 	}
 
 	private String createExecFile() throws IOException {
