@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Brock Janiczak - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.examples;
 
@@ -27,7 +28,7 @@ import org.jacoco.report.html.HTMLFormatter;
  * This example creates a HTML report for eclipse like projects based on a
  * single execution data store called jacoco.exec. The report contains no
  * grouping information.
- * 
+ *
  * The class files under test must be compiled with debug information, otherwise
  * source highlighting will not work.
  */
@@ -44,7 +45,7 @@ public class ReportGenerator {
 
 	/**
 	 * Create a new generator based for the given project.
-	 * 
+	 *
 	 * @param projectDirectory
 	 */
 	public ReportGenerator(final File projectDirectory) {
@@ -57,7 +58,7 @@ public class ReportGenerator {
 
 	/**
 	 * Create the report.
-	 * 
+	 *
 	 * @throws IOException
 	 */
 	public void create() throws IOException {
@@ -95,8 +96,8 @@ public class ReportGenerator {
 
 		// Populate the report structure with the bundle coverage information.
 		// Call visitGroup if you need groups in your report.
-		visitor.visitBundle(bundleCoverage, new DirectorySourceFileLocator(
-				sourceDirectory, "utf-8", 4));
+		visitor.visitBundle(bundleCoverage,
+				new DirectorySourceFileLocator(sourceDirectory, "utf-8", 4));
 
 		// Signal end of structure information to allow report to write all
 		// information out
@@ -121,7 +122,7 @@ public class ReportGenerator {
 
 	/**
 	 * Starts the report generation process
-	 * 
+	 *
 	 * @param args
 	 *            Arguments to the application. This will be the location of the
 	 *            eclipse projects that will be used to generate reports for
@@ -129,8 +130,8 @@ public class ReportGenerator {
 	 */
 	public static void main(final String[] args) throws IOException {
 		for (int i = 0; i < args.length; i++) {
-			final ReportGenerator generator = new ReportGenerator(new File(
-					args[i]));
+			final ReportGenerator generator = new ReportGenerator(
+					new File(args[i]));
 			generator.create();
 		}
 	}
