@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2023 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.report.internal.html.resources;
 
@@ -74,13 +75,15 @@ public class ResourcesTest {
 	@Test
 	public void testGetElementStyle() {
 		assertEquals("el_group", Resources.getElementStyle(ElementType.GROUP));
-		assertEquals("el_bundle", Resources.getElementStyle(ElementType.BUNDLE));
+		assertEquals("el_bundle",
+				Resources.getElementStyle(ElementType.BUNDLE));
 		assertEquals("el_package",
 				Resources.getElementStyle(ElementType.PACKAGE));
 		assertEquals("el_source",
 				Resources.getElementStyle(ElementType.SOURCEFILE));
 		assertEquals("el_class", Resources.getElementStyle(ElementType.CLASS));
-		assertEquals("el_method", Resources.getElementStyle(ElementType.METHOD));
+		assertEquals("el_method",
+				Resources.getElementStyle(ElementType.METHOD));
 	}
 
 }
